@@ -28,7 +28,7 @@ class CoreApplicationMenu(object):
         self.pkg_to_app = {}
         # cache
         self.pickle = {}
-	self.popcon_max = 1
+	self.popcon_max = 10
         
     def createMenuCache(self, targetdir, fname="menu.p"):
         self.desktopEntriesSeen.clear()
@@ -87,6 +87,7 @@ class CoreApplicationMenu(object):
                         item.free = False
                     # check for third party apps
                     item.channel = entry.DesktopEntry.get("X-AppInstall-Channel")
+                    item.isv = entry.DesktopEntry.get("X-AppInstall-ISV")
                     thirdparty =  entry.DesktopEntry.get("X-AppInstall-Proprietary")
                     if thirdparty != "":
                         item.thirdparty = bool(thirdparty)
@@ -101,6 +102,9 @@ class CoreApplicationMenu(object):
                         item.replaces = replaces
                     # Icon
                     item.iconname = entry.DesktopEntry.get("X-AppInstall-Icon", "") or entry.DesktopEntry.getIcon() or "applications-other"
+
+                    if item.iconname.endswith(".png") or item.iconname.endswith(".xpm") or item.iconname.endswith(".svg"):
+                    	item.iconname = item.iconname[:-4]
                     item.mime = entry.DesktopEntry.get('MimeType', list=True)
                     item.codecs = entry.DesktopEntry.get("X-AppInstall-Codecs").split(';')
                     item.patentBadness = entry.DesktopEntry.get("X-AppInstall-PatentBadness", type='boolean')
@@ -122,11 +126,17 @@ class CoreApplicationMenu(object):
                     else:
                         item.menupath = None
                     self.pickle[parent].append(item)
-                else:
+                elif name:
                     try:
-                        print "Got non-package menu entry %s" % entry
+                        print "Skipped %s: not associated with a package" % entry
                     except UnicodeEncodeError:
                         pass
+                else:
+                    try:
+                        print "Skipped %s: does not include a menu name" % entry
+                    except UnicodeEncodeError:
+                        pass
+ 
             elif isinstance(entry, xdg.Menu.Header):
                 print "got header"
 
@@ -174,6 +184,8 @@ class Application(MenuItem):
         self.component = None
         # channel the pacakge is in (e.g. skype)
         self.channel = None
+        # Name of the independent software vendor
+        self.isv = None
         # states
         self.popcon = 1            # the raw popcon data
         self.rank = 1              # used by the ranking algo
